@@ -103,7 +103,7 @@ int get_dist(Breakpoint * tmp) {
 
 long Breakpoint::overlap(Breakpoint * tmp) {
 	bool flag = false;
-//flag = ((*tmp->get_coordinates().support.begin()).second.SV & DEL);
+	//flag = ((*tmp->get_coordinates().support.begin()).second.SV & INS);
 	int max_dist = std::min(get_dist(tmp), get_dist(this)); // Parameter::Instance()->max_dist
 	if (flag) {
 		std::cout << "\t Overlap: " << max_dist << " start: " << tmp->get_coordinates().start.min_pos << " " << positions.start.min_pos << " stop :" << tmp->get_coordinates().stop.max_pos << " " << positions.stop.max_pos;
@@ -133,7 +133,7 @@ long Breakpoint::overlap(Breakpoint * tmp) {
 	//Standard merging.
 	if (is_same_strand(tmp) && (abs(tmp->get_coordinates().start.min_pos - positions.start.min_pos) < max_dist && abs(tmp->get_coordinates().stop.max_pos - positions.stop.max_pos) < max_dist)) {
 		if (flag) {
-			cout << "\tHIT" << endl;
+			cout << "\tMERGED" << endl;
 		}
 		return 0;
 	}
@@ -292,9 +292,11 @@ void Breakpoint::calc_support() {
 
 	if (get_SVtype() & TRA) { // we cannot make assumptions abut support yet.
 		set_valid((bool) (get_support() >= 1)); // this is needed as we take each chr independently and just look at the primary alignment
-	} else if (get_support() >= Parameter::Instance()->min_support) {
+	} else if (get_support() >= min(3, Parameter::Instance()->min_support)) { // to allow the merge of split SV
 		predict_SV();
-		set_valid((bool) (get_length() > Parameter::Instance()->min_length));
+		if (get_support() >= Parameter::Instance()->min_support) {
+			set_valid((bool) (get_length() > Parameter::Instance()->min_length));
+		}
 	}
 }
 
@@ -425,13 +427,19 @@ void Breakpoint::predict_SV() {
 	long counts = 0;
 	int maxim = 0;
 	long coord = 0;
+	long min_start = 0;
+	long max_stop = 0;
 	if (num > 0) {
+		min_start = (*starts.begin()).first;
 		//find the start coordinate:
 		for (map<long, int>::iterator i = starts.begin(); i != starts.end(); i++) {
 			if ((*i).second > maxim) {
 				coord = (*i).first;
 				maxim = (*i).second;
 			}
+			if ((*i).first < min_start) {
+				min_start = (*i).first;
+			}
 		}
 		if (maxim < 5) {
 			this->positions.start.most_support = get_median(start2);	//check if "input"!
@@ -450,6 +458,9 @@ void Breakpoint::predict_SV() {
 				coord = (*i).first;
 				maxim = (*i).second;
 			}
+			if ((*i).first > max_stop) {
+				max_stop = (*i).first;
+			}
 		}
 		if (maxim < 5) {
 			this->positions.stop.most_support = get_median(stops2);	// mean / counts;
@@ -483,6 +494,7 @@ void Breakpoint::predict_SV() {
 		}
 		starts.clear();
 		stops.clear();
+
 		//strand information:
 		for (size_t i = 0; i < strands.size(); i++) {
 			maxim = 0;
@@ -503,17 +515,17 @@ void Breakpoint::predict_SV() {
 	}
 
 	if (!scan_reads) {
-	//	std::cout<<"Test strand"<<std::endl;
+		//	std::cout<<"Test strand"<<std::endl;
 		//if forcecalling we need to define the strands:
 		std::map<std::string, read_str>::iterator it = positions.support.find("input");
 
 		//no output!??
 		/*if ((*it).second.strand.first) {
-			std::cout << "s1: true" << endl;
-		}
-		if ((*it).second.strand.second) {
-			std::cout << "s2: true" << endl;
-		}*/
+		 std::cout << "s1: true" << endl;
+		 }
+		 if ((*it).second.strand.second) {
+		 std::cout << "s2: true" << endl;
+		 }*/
 		if (it != positions.support.end()) {
 			this->strand.push_back(translate_strand((*it).second.strand));
 		}
@@ -703,3 +715,16 @@ std::string Breakpoint::to_string(RefVector ref) {
 	return ss.str();
 }
 
+void Breakpoint::integrate(Breakpoint * p) {
+	//carry over support:
+	position_str old = p->get_coordinates();
+	for (std::map<std::string, read_str>::iterator i = old.support.begin(); i != old.support.end(); i++) {
+		this->positions.support[(*i).first] = (*i).second;
+		//	cout << "Added " << (*i).first << endl;
+	}
+
+//	cout << "Recompute: " << endl;
+	this->calc_support();
+	set_valid((bool) (get_length() > Parameter::Instance()->min_length));
+}
+
